<?php

/**
 * Description of class
 *
 * @author naren
 */
class Smartech
{

    private static $initiated = false;
    private static $smartechTable = "smartech_settings";
    private static $pluginDir;
    private static $configJs;
    private static $addTocart = false;

    function __construct() {
		$this->json_api = 'http://api.netcoresmartech.com/apiv2';
    }
    
    public static function init()
    {
        if (!self::$initiated) {
            self::init_hooks();
            self::init_smartech_hooks();
        }
        self::$pluginDir = plugin_dir_path(__FILE__);
        self::$configJs = self::$pluginDir . "smartech_config.js";
    }

    public static function plugin_activation()
    {
        global $wpdb;
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	$query = array();
        $query[] = "CREATE TABLE IF NOT EXISTS " . $wpdb->prefix . self::$smartechTable . " (web_tracking_id CHAR(52), siteid char(32),"
            . " smt_pk VARCHAR(50), listid int(5), idc VARCHAR(15), bpn_api_key VARCHAR(200), bpn_sender_id VARCHAR(15), bpn_project_id VARCHAR(100), bpn_app_id VARCHAR(100), web_push_icon VARCHAR(200), web_push_apikey VARCHAR(200), bpn_enable TINYINT(1),"
            . " track_status CHAR(10))";
	$query[] = "CREATE TABLE IF NOT EXISTS `smartech_options` (
  `option_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `option_name` varchar(191) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `option_value` longtext COLLATE utf8mb4_unicode_ci NOT NULL,
  PRIMARY KEY (`option_id`),
  UNIQUE KEY `option_name` (`option_name`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci";
	for($i=0;$i<count($query);$i++){
        	$wpdb->query($query[$i]);
	}
    }

    public static function plugin_deactivation()
    {
        global $wpdb;
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
	$query = array();
        $query[] = "DROP TABLE IF EXISTS " . $wpdb->prefix . self::$smartechTable;
        $query[] = "DROP TABLE IF EXISTS smartech_options";
	for($i=0;$i<count($query);$i++){
        	$wpdb->query($query[$i]);
	}
    }

    public static function init_hooks()
    {
        self::$initiated = true;
        add_action("admin_menu", array("Smartech", "admin_menu"), 5);
        add_action("wp_ajax_get_smartech_configration", array("Smartech", "get_conficuration"));
        add_action("wp_ajax_post_smartech_configuration", array("Smartech", "save_configuration"));
        add_filter("plugin_action_links_" . plugin_basename(plugin_dir_path(__FILE__) . "smartech.php"), array("Smartech", "admin_plugin_settings_link"));
    }

    public static function init_smartech_hooks()
    {
        add_action("wp_head", array("Smartech", "smartech_header_script"));
    }

    public static function admin_head()
    {
        if (!current_user_can("manage_options")) {
            return;
        }
    }

    public static function admin_menu()
    {
        add_menu_page('Smartech Settings', 'Smartech', 'manage_options', 'smartech', array("Smartech", "display_page"));
    }

    public static function admin_plugin_settings_link($links)
    {
        $settings_link = '<a href="admin.php?page=smartech">' . __('Settings') . '</a>';
        array_unshift($links, $settings_link);
        return $links;
    }

    public static function display_page()
    {
        $file = SMARTECH__PLUGIN_DIR . 'configuration_view.php';
        include( $file );
    }

    public static function get_conficuration($type)
    {
        global $wpdb;
        $school_query = "SELECT * from ".$wpdb->prefix . self::$smartechTable;
        $results = $wpdb->get_results($school_query);
        if ($type === "plain") {
            return $results[0];
        }
        $response = array(
            "code" => 200,
            "msg" => "success",
            "data" => $results[0]
        );
        echo json_encode($response);
        wp_die();
    }

    public static function save_configuration()
    {
        global $wpdb;
        $check_column = $wpdb->get_row( "SHOW COLUMNS FROM ".$wpdb->prefix . self::$smartechTable." LIKE 'bpn_enable'" );
        if($wpdb->num_rows === 0) {
            $alterQuery = "ALTER TABLE ".$wpdb->prefix . self::$smartechTable." ADD COLUMN bpn_enable TINYINT(1) ";
            $wpdb->query($alterQuery);
        }
        $check_column = $wpdb->get_row( "SHOW COLUMNS FROM ".$wpdb->prefix . self::$smartechTable." LIKE 'web_push_icon'" );
        if($wpdb->num_rows === 0) {
            $alterQuery = "ALTER TABLE ".$wpdb->prefix . self::$smartechTable." ADD COLUMN web_push_icon VARCHAR(200) ";
            $wpdb->query($alterQuery);
        }
        $check_column = $wpdb->get_row( "SHOW COLUMNS FROM ".$wpdb->prefix . self::$smartechTable." LIKE 'web_push_apikey'" );
        if($wpdb->num_rows === 0) {
            $alterQuery = "ALTER TABLE ".$wpdb->prefix . self::$smartechTable." ADD COLUMN web_push_apikey VARCHAR(200) ";
            $wpdb->query($alterQuery);
        }
        $check_column = $wpdb->get_row( "SHOW COLUMNS FROM ".$wpdb->prefix . self::$smartechTable." LIKE 'bpn_project_id'" );
        if($wpdb->num_rows === 0) {
            $alterQuery = "ALTER TABLE ".$wpdb->prefix . self::$smartechTable." ADD COLUMN bpn_project_id VARCHAR(200) ";
            $wpdb->query($alterQuery);
        }
        $check_column = $wpdb->get_row( "SHOW COLUMNS FROM ".$wpdb->prefix . self::$smartechTable." LIKE 'bpn_app_id'" );
        if($wpdb->num_rows === 0) {
            $alterQuery = "ALTER TABLE ".$wpdb->prefix . self::$smartechTable." ADD COLUMN bpn_app_id VARCHAR(200) ";
            $wpdb->query($alterQuery);
        }
        $check_column = $wpdb->get_row( "SHOW COLUMNS FROM ".$wpdb->prefix . self::$smartechTable." LIKE 'idc'" );
        if($wpdb->num_rows === 0) {
            $alterQuery = "ALTER TABLE ".$wpdb->prefix . self::$smartechTable." ADD COLUMN idc VARCHAR(15) ";
            $wpdb->query($alterQuery);
        }
        $deleteQuery = "DELETE from ".$wpdb->prefix . self::$smartechTable."";
        $wpdb->query($deleteQuery);

	$create_opt = "CREATE TABLE IF NOT EXISTS `smartech_options` (
  			`option_id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  			`option_name` varchar(191) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  			`option_value` longtext COLLATE utf8mb4_unicode_ci NOT NULL,
  			PRIMARY KEY (`option_id`),
  			UNIQUE KEY `option_name` (`option_name`)
			) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci";
        $wpdb->query($create_opt);

        $allowedParams = array(
            "web_tracking_id", "siteid", "smt_pk", "listid", "idc", "bpn_api_key", "bpn_sender_id", "bpn_project_id", "bpn_app_id", "track_status", "web_push_icon", "web_push_apikey", "bpn_enable"
        );
        $insertQuery = "INSERT INTO ".$wpdb->prefix . self::$smartechTable." (web_tracking_id, siteid, smt_pk, listid, idc, bpn_api_key, bpn_sender_id, bpn_project_id, bpn_app_id, track_status, web_push_icon, web_push_apikey, bpn_enable) VALUES(";
        foreach ($allowedParams as $value) {
            $paramValue = (isset($_POST[$value])) ? $_POST[$value] : "";
            $insertQuery .= "'" . $paramValue . "',";
        }
        $insertQuery1 = trim($insertQuery, ",");
        $insertQuery1 .= ");";
        $wpdb->query($insertQuery1);
        $response = array(
            "code" => 200,
            "msg" => "success"
        );
        self::writeSmartechBaseIntegration($_POST);
        /*if (!empty($_POST["bpn_api_key"]) && !empty($_POST["bpn_sender_id"])) {
            self::writeSWFile($_POST);
        } else {
            self::deleteSWFile();
        }*/
        if(!empty($_POST["web_push_icon"])) {
            self::writeSWFile($_POST);
        } else {
            self::deleteSWFile();
        }
        echo json_encode($response);
        wp_die();
    }

    public static function writeSmartechBaseIntegration($clientData)
    {
        $file = self::$pluginDir . "smartech_config.js";
        $configScript = "smartech('create', '" . $clientData["web_tracking_id"] . "');\n";
        $configScript .= "smartech('register', '" . $clientData["siteid"] . "');\n";
        if ($clientData["track_status"] === "enable") {
            $configScript .= "smartech('dispatch', 1, {});\n";
        }
        $listid = (isset($clientData["listid"]) && !empty($clientData["listid"])) ? $clientData["listid"] : "''";
        $configScript .= "var listid = " . $listid . ";\n";
        $configScript .= "var smt_pk = '" . $clientData["smt_pk"] . "';";
        $open = fopen($file, "w");
        fputs($open, $configScript);
    }

    public static function writeSWFile($clientData)
    {
        $path = get_home_path();
        $configSW = array(
            "user_key" => $clientData["web_tracking_id"],
            "siteid" => $clientData["siteid"],
            "apiKey" => $clientData["bpn_api_key"],
            "messagingSenderId" => $clientData["bpn_sender_id"],
            "projectId" => $clientData["bpn_project_id"],
            "appId" => $clientData["bpn_app_id"]
        );
        if(!empty($clientData["idc"])) {
            $configSW["idc"] = $clientData["idc"];
        } else {
            unset($configSW["idc"]);
        }
        $swScript = json_encode($configSW);
        $swScript = "var config = " . $swScript . ";\n";
        $swScript .= "importScripts('" . SMARTECH_SW_PATH . "');";
        $file = "sw.js";
        $open = fopen($path . $file, "w");
        fputs($open, $swScript);
    }

    public static function deleteSWFile()
    {
        $file = get_home_path() . "sw.js";
        unlink($file);
    }

    public static function get_smt_pk($config)
    {
        global $current_user;
        switch ($config->smt_pk) {
            case "email":
                return $current_user->user_email;
            case "mobile":
                return $current_user->user_mobile;
            case "userid":
                return $current_user->ID;
            case "username":
                return $current_user->user_login;
            default :
                return '';
        }
    }

    public static function smartech_header_script()
    {
        $config = self::get_conficuration("plain");
        $identity = self::get_smt_pk($config);
        self::bindContactForm7Submit();
        $configJs = plugins_url("smartech", "") . "/smartech_config.js";
        $script = '<script type="text/javascript" src="' . SMARTECH_SCRIPT_PATH . '"></script>';
        $script .= '<script type="text/javascript" id="smartech_config" src="' . $configJs . '"></script>';
        $script .= '<script type="text/javascript">smartech("identify","' . $identity . '");</script>';
        echo $script;
    }

    public static function bindContactForm7Submit()
    {
        ?>
        <script>
            document.addEventListener('wpcf7submit', function (event) {
                var inputs = event.detail.inputs;
                var formdata = {};
                for (var i = 0; i < inputs.length; i++) {
                    if (smt_pk === inputs[i].name) {
                        formdata['pk^' + smt_pk] = inputs[i].value;
                    } else {
                        formdata[inputs[i].name.toUpperCase()] = inputs[i].value;
                    }
                }
                smartech('contact', listid, formdata);
            }, false);
        </script>
        <?php
    }

    public static function hit_smartech($event_id, $payload, $type)
    {
        ?>
        <script type="text/javascript">
            var type = '<?php echo $type ?>';
            if (type === 'form') {
                smartech("contact", listid, <?php echo $payload ?>);
                console.log("raised profile push event");
            } else {
                smartech("dispatch", <?php echo $event_id ?>, <?php echo $payload ?>);
                console.log("raised <?php echo $event_id ?> event");
            }
        </script>
        <?php
    }

    function sm_update_option( $key, $option) {
	global $wpdb;

        $check_column = $wpdb->query($wpdb->prepare("INSERT INTO smartech_options (option_name, option_value) VALUES (%s,%s) ON DUPLICATE KEY UPDATE option_value=%s",$key,$option,$option));
	return $check_column;
    }
    function sm_get_option( $key ) {
	global $wpdb;
	$smt_query = "SELECT option_value from smartech_options where option_name='".$key."'";
        $results = $wpdb->get_results($smt_query);

        return $results[0]->option_value;
    }

}
